@@ -13,16 +13,16 @@ class TargetsTemplate(CMakeDepsFileTemplate):
 
     @property
     def filename(self):
-        name = "" if not self.find_module_mode else "module-"
+        name = "" if not self.generating_module else "module-"
         name += self.file_name + "Targets.cmake"
         return name
 
     @property
     def context(self):
-        data_pattern = "${_DIR}/" if not self.find_module_mode else "${_DIR}/module-"
+        data_pattern = "${_DIR}/" if not self.generating_module else "${_DIR}/module-"
         data_pattern += "{}-*-data.cmake".format(self.file_name)
 
-        target_pattern = "" if not self.find_module_mode else "module-"
+        target_pattern = "" if not self.generating_module else "module-"
         target_pattern += "{}-Target-*.cmake".format(self.file_name)
 
         cmake_target_aliases = self.conanfile.cpp_info.\
@@ -67,8 +67,6 @@ class TargetsTemplate(CMakeDepsFileTemplate):
             if(NOT TARGET ${_COMPONENT})
                 add_library(${_COMPONENT} INTERFACE IMPORTED)
                 conan_message(STATUS "Conan: Component target declared '${_COMPONENT}'")
-            else()
-                message(WARNING "Component target name '${_COMPONENT}' already exists.")
             endif()
         endforeach()
 
