@@ -2,18 +2,18 @@ import copy
 import os
 from collections import OrderedDict
 
-from conans.model.build_info import DefaultOrderedDict
+from conans.model.build_info import DefaultOrderedDict, CppInfoDefaultValues
 
 _DIRS_VAR_NAMES = ["includedirs", "srcdirs", "libdirs", "resdirs", "bindirs", "builddirs",
-                   "frameworkdirs"]
+                   "frameworkdirs", "objects"]
 _FIELD_VAR_NAMES = ["system_libs", "frameworks", "libs", "defines", "cflags", "cxxflags",
-                    "sharedlinkflags", "exelinkflags", "objects"]
+                    "sharedlinkflags", "exelinkflags"]
 _ALL_NAMES = _DIRS_VAR_NAMES + _FIELD_VAR_NAMES
 
 
 class _NewComponent(object):
 
-    def __init__(self):
+    def __init__(self, with_defaults=False):
         # ###### PROPERTIES
         self._generator_properties = None
 
@@ -40,6 +40,11 @@ class _NewComponent(object):
         self.sysroot = None
         self.requires = None
 
+        if with_defaults:
+            self.includedirs = ["include"]
+            self.libdirs = ["lib"]
+            self.bindirs = ["bin"]
+
     @property
     def required_component_names(self):
         """ Names of the required components of the same package (not scoped with ::)"""
@@ -70,10 +75,10 @@ class _NewComponent(object):
 
 class NewCppInfo(object):
 
-    def __init__(self):
-        self.components = DefaultOrderedDict(lambda: _NewComponent())
+    def __init__(self, with_defaults=False):
+        self.components = DefaultOrderedDict(lambda: _NewComponent(with_defaults))
         # Main package is a component with None key
-        self.components[None] = _NewComponent()
+        self.components[None] = _NewComponent(with_defaults)
         self._aggregated = None  # A _NewComponent object with all the components aggregated
 
     def __getattr__(self, attr):
@@ -138,11 +143,20 @@ class NewCppInfo(object):
 
     def set_relative_base_folder(self, folder):
         """Prepend the folder to all the directories"""
-        for cname, c in self.components.items():
+        for component in self.components.values():
             for varname in _DIRS_VAR_NAMES:
-                origin = getattr(self.components[cname], varname)
+                origin = getattr(component, varname)
                 if origin is not None:
                     origin[:] = [os.path.join(folder, el) for el in origin]
+            if component._generator_properties is not None:
+                updates = {}
+                for prop_name, value in component._generator_properties.items():
+                    if prop_name == "cmake_build_modules":
+                        if isinstance(value, list):
+                            updates[prop_name] = [os.path.join(folder, v) for v in value]
+                        else:
+                            updates[prop_name] = os.path.join(folder, value)
+                component._generator_properties.update(updates)
 
     def get_sorted_components(self):
         """Order the components taking into account if they depend on another component in the
@@ -191,15 +205,6 @@ class NewCppInfo(object):
             self._aggregated.components[None] = result
         return self._aggregated
 
-    def copy(self):
-        # Only used at the moment by layout() editable merging build+source .cpp data
-        ret = NewCppInfo()
-        ret._generator_properties = copy.copy(self._generator_properties)
-        ret.components = DefaultOrderedDict(lambda: _NewComponent())
-        for comp_name in self.components:
-            ret.components[comp_name] = copy.copy(self.components[comp_name])
-        return ret
-
     @property
     def required_components(self):
         """Returns a list of tuples with (require, component_name) required by the package
@@ -271,3 +276,7 @@ def fill_old_cppinfo(origin, old_cpp):
                 setattr(old_cpp, varname, copy.copy(value))
         if origin._generator_properties is not None:
             old_cpp._generator_properties = copy.copy(origin._generator_properties)
+
+    # We change the defaults so the new components the user is going to declare in package_info
+    # have also defaults, not only the declared in the `self.cpp.package`
+    old_cpp._default_values = CppInfoDefaultValues(includedir="include", libdir="lib", bindir="bin")
